%define	oname	Scorched3D

Summary:	3D artillery game similar to Scorched Earth
Name:		scorched3d
Version:	44
Release:	%mkrel 18
License:	GPLv2+ and CC-BY-SA
Group:		Games/Strategy
URL:		http://www.scorched3d.co.uk
Source0:	https://downloads.sourceforge.net/scorched3d/%{oname}-%{version}-src.tar.gz
# openal-soft does not provide openal-config, so fake it
Source1:	openal-config

# Patches sourced from Fedora or Debian.
Patch0:		scorched3d-syslibs.patch
Patch1:		scorched3d-help.patch
Patch2:		scorched3d-freetype-buildfix.patch
Patch3:		scorched3d-sys-lua.patch
Patch4:		scorched3d-returntype.patch
Patch5:		scorched3d-wx3.0.patch
Patch6:		scorched3d-lua54.patch
Patch7:		scorched3d-fix-hang-on-fast-machines.patch

BuildRequires:	imagemagick
BuildRequires:	libtool
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(freealut)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(lua)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(SDL_net)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(vorbisfile)
BuildRequires:	pkgconfig(zlib)

# (akien) Not compatible with wxgtk > 3.0.
BuildRequires:	wxgtk3.0-devel
BuildConflicts:	wxgtk3.1-devel

%description
Scorched is a game loosely-based on the classic DOS game Scorched
Earth, "The Mother Of All Games", with fully destructible 3D landscapes
and stunning visual effects.

"Scorched Earth is a simple, yet exciting artillery combat game,
based on an auspicious history of artillery games."
(Review of Scorched Earth at ClassicGaming.com)

In its simplest form Scorched is an artillery game.
Tanks take turns to earn money by destroying opponents in an arena.
Scorched attempts to recreate the simple yet addictive game play
of the original game, adding amongst other new features a 3D island
environment and LAN and internet play.

%prep
%autosetup -p1 -n scorched
install -m 755 %{_sourcedir}/openal-config .

# ensure we use the system versions of these
rm -f src/common/common/snprintf.c
rm -f src/common/lua/l*.{cpp,h}
rm -f src/common/lua/print.cpp

%build
touch NEWS AUTHORS ChangeLog
autoreconf -vfi
export OPENAL_CONFIG=$PWD/openal-config
%configure \
	--bindir=%{_gamesbindir} \
	--datadir=%{_gamesdatadir}/%{name} \
	--disable-openaltest

%make_build

%install
%make_install

rm -rf %{buildroot}%{_gamesdatadir}/%{name}/documentation

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Scorched3D
GenericName=Artillery game
Comment=3D artillery game similar to Scorched Earth
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Game;StrategyGame;
EOF

# Extract 48x48 icon
convert data/images/tank2.ico tank2.png
install -D -m 644 tank2-0.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

%files
%doc README documentation/*
%{_gamesbindir}/%{name}*
%{_gamesdatadir}/%{name}
%{_iconsdir}/hicolor/48x48/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop


%changelog
* Mon Mar 21 2022 akien <akien> 44-18.mga9
+ Revision: 1813676
- Build with wxgtk3.0, not compatible with 3.1 (mga#30156)
- Sync patches with Fedora/Debian, build against lua 5.4 and fix hang on fast machines

* Sat Jan 15 2022 wally <wally> 44-17.mga9
+ Revision: 1768503
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 44-16.mga9
+ Revision: 1765732
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Tue Mar 30 2021 wally <wally> 44-15.mga9
+ Revision: 1712042
- rebuild with updated lua 5.1

* Fri Jan 01 2021 wally <wally> 44-14.mga8
+ Revision: 1667726
- rebuild for wxgtk pre 3.1.5 snapshot

* Wed Dec 02 2020 luigiwalser <luigiwalser> 44-13.mga8
+ Revision: 1651370
- rebuild for glew

* Sun Aug 16 2020 wally <wally> 44-12.mga8
+ Revision: 1614367
- rebuild for new wxgtk 3.1.4

* Tue Feb 18 2020 umeabot <umeabot> 44-11.mga8
+ Revision: 1538030
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 12 2019 wally <wally> 44-10.mga8
+ Revision: 1459489
- rebuild for wxgtk 3.1.3

* Sun Jul 14 2019 wally <wally> 44-9.mga8
+ Revision: 1421077
- rebuild with gtk3 enabled wxgtk 3.1.2

* Sun Sep 23 2018 umeabot <umeabot> 44-8.mga7
+ Revision: 1300960
- Mageia 7 Mass Rebuild

* Sun Dec 03 2017 daviddavid <daviddavid> 44-7.mga7
+ Revision: 1180813
- rebuild for new glew 2.1.0

* Mon Oct 09 2017 daviddavid <daviddavid> 44-6.mga7
+ Revision: 1170475
- build against lua5.1
- patch5: port to wxgtk 3.0
- patch4: fix build with gcc7
+ tv <tv>
- rebuild for new libglew

* Wed Feb 17 2016 umeabot <umeabot> 44-5.mga6
+ Revision: 962761
- Mageia 6 Mass Rebuild

* Sat Nov 07 2015 daviddavid <daviddavid> 44-4.mga6
+ Revision: 898364
- fix build with newer freetype2 (remove no more needed freetype2.patch)

* Mon Aug 24 2015 sander85 <sander85> 44-3.mga6
+ Revision: 869156
- Rebuild for glew 1.13.0

* Wed Jun 24 2015 akien <akien> 44-2.mga6
+ Revision: 842033
- Rebuild for GLEW 1.12

* Fri Jan 16 2015 akien <akien> 44-1.mga5
+ Revision: 810908
- Move RPM group to Games/Strategy
- Improve description and desktop file
- Move desktop category to StrategyGame
- Version 44
- Build against system lua

* Wed Oct 15 2014 umeabot <umeabot> 43.3d-8.mga5
+ Revision: 749931
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 43.3d-7.mga5
+ Revision: 689075
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 luigiwalser <luigiwalser> 43.3d-6.mga5
+ Revision: 670278
- rebuild for glew

* Tue Mar 04 2014 akien <akien> 43.3d-5.mga5
+ Revision: 599468
- Add a patch for the freetype2 includes and add the corresponding dependency

* Sat Oct 19 2013 umeabot <umeabot> 43.3d-4.mga4
+ Revision: 530461
- Mageia 4 Mass Rebuild

* Wed Jul 24 2013 sander85 <sander85> 43.3d-3.mga4
+ Revision: 457721
- Rebuild for new glew

* Tue Jun 04 2013 fwang <fwang> 43.3d-2.mga4
+ Revision: 436997
- rebuild for new libpng

* Mon Jan 21 2013 stormi <stormi> 43.3d-1.mga3
+ Revision: 390434
- clean spec
- imported package scorched3d

